Configuring the user interface
------------------------------

.. _relation_tags:

Relation tags
~~~~~~~~~~~~~
.. automodule:: cubicweb.rtags

.. _uicfg:

The uicfg module
~~~~~~~~~~~~~~~~

.. note::

 The part of uicfg that deals with primary views is in the
 :ref:`primary_view_configuration` chapter.

.. automodule:: cubicweb.web.views.uicfg


The uihelper module
~~~~~~~~~~~~~~~~~~~

.. automodule:: cubicweb.web.uihelper

